@@ -34,7 +34,7 @@ def setup_parser():
         action="store_true", default=False)
     parser.add_argument(
         '-L', '--local-mods',
-        help='Disallow deployment of locally-modified charms',
+        help='Allow deployment of locally-modified charms',
         dest="no_local_mods", default=True, action='store_false')
     parser.add_argument(
         '-u', '--update-charms',
