@@ -1,10 +1,7 @@
-import errno
-import os
-import socket
 import time
 
 from .base import BaseEnvironment
-from ..utils import ErrorExit, _get_juju_home, yaml_load
+from ..utils import ErrorExit
 
 from jujuclient import (
     EnvError,
@@ -27,28 +24,6 @@ class GoEnvironment(BaseEnvironment):
         self.api_endpoint = endpoint
         self.client = None
 
-    def _get_token(self):
-        home = _get_juju_home()
-        jenv = os.path.join(
-            home, 'environments', '%s.jenv' % self.name)
-        if not os.path.exists(jenv):
-            with open(os.path.join(home, 'environments.yaml')) as fh:
-                data = yaml_load(fh.read())
-                token = data.get('environments', {}).get(self.name, {}).get(
-                    'admin-secret')
-                if token is None:
-                    raise EnvError(
-                        {'Error': "Environment config not found %s" % self.name
-                         })
-                return token
-        with open(jenv) as fh:
-            data = yaml_load(fh.read())
-            token = data.get('bootstrap-config', {}).get(
-                'admin-secret')
-            if token is None:
-                raise EnvError("Could not find admin-secret for environment")
-        return token
-
     def add_unit(self, service_name, machine_spec):
         return self.client.add_unit(service_name, machine_spec)
 
@@ -63,22 +38,8 @@ class GoEnvironment(BaseEnvironment):
             self.client.close()
 
     def connect(self):
-        if not self.api_endpoint:
-            # Should really have a cheaper/faster way of getting the endpoint
-            # ala juju status 0 for a get_endpoint method.
-            self.get_cli_status()
-        while True:
-            try:
-                self.client = EnvironmentClient(self.api_endpoint)
-            except socket.error as err:
-                if not err.errno in (
-                        errno.ETIMEDOUT, errno.ECONNREFUSED, errno.ECONNRESET):
-                    raise
-                time.sleep(1)
-                continue
-            else:
-                break
-        self.client.login(self._get_token())
+        self.log.debug("Connecting to environment...")
+        self.client = EnvironmentClient.connect(self.name)
         self.log.debug("Connected to environment")
 
     def get_config(self, svc_name):
@@ -92,14 +53,6 @@ class GoEnvironment(BaseEnvironment):
                 return {}
             raise
 
-    def get_cli_status(self):
-        status = super(GoEnvironment, self).get_cli_status()
-        # Opportunistic, see connect method comment.
-        if not self.api_endpoint:
-            self.api_endpoint = "wss://%s:17070/" % (
-                status["machines"]["0"]["dns-name"])
-        return status
-
     def expose(self, name):
         return self.client.expose(name)
 
